EXPORTS
	??1CDecPkcs12SafeBag@PKCS12@@UAE@XZ @ 1 NONAME ; PKCS12::CDecPkcs12SafeBag::~CDecPkcs12SafeBag(void)
	?AttributeId@CDecPkcs12Attribute@PKCS12@@QBEABVTDesC16@@XZ @ 2 NONAME ; class TDesC16 const & PKCS12::CDecPkcs12Attribute::AttributeId(void) const
	?AttributeValue@CDecPkcs12Attribute@PKCS12@@QBEABV?$RPointerArray@VTDesC8@@@@XZ @ 3 NONAME ; class RPointerArray<class TDesC8> const & PKCS12::CDecPkcs12Attribute::AttributeValue(void) const
	?AuthenticatedSafe@CDecPkcs12@PKCS12@@QBEABVCPKCS7ContentInfo@@XZ @ 4 NONAME ; class CPKCS7ContentInfo const & PKCS12::CDecPkcs12::AuthenticatedSafe(void) const
	?AuthenticatedSafeContents@CDecPkcs12@PKCS12@@QBEABV?$RPointerArray@VCPKCS7ContentInfo@@@@XZ @ 5 NONAME ; class RPointerArray<class CPKCS7ContentInfo> const & PKCS12::CDecPkcs12::AuthenticatedSafeContents(void) const
	?BagAttributes@CDecPkcs12SafeBag@PKCS12@@QBEABV?$RPointerArray@VCDecPkcs12Attribute@PKCS12@@@@XZ @ 6 NONAME ; class RPointerArray<class PKCS12::CDecPkcs12Attribute> const & PKCS12::CDecPkcs12SafeBag::BagAttributes(void) const
	?BagID@CDecPkcs12SafeBag@PKCS12@@QBE?AW4TBagId@12@XZ @ 7 NONAME ; enum PKCS12::CDecPkcs12SafeBag::TBagId PKCS12::CDecPkcs12SafeBag::BagID(void) const
	?BagValue@CDecPkcs12SafeBag@PKCS12@@QBEABVTDesC8@@XZ @ 8 NONAME ; class TDesC8 const & PKCS12::CDecPkcs12SafeBag::BagValue(void) const
	?CertId@CDecPkcs12CertBag@PKCS12@@QBEABVTDesC16@@XZ @ 9 NONAME ; class TDesC16 const & PKCS12::CDecPkcs12CertBag::CertId(void) const
	?CertValue@CDecPkcs12CertBag@PKCS12@@QBEABVTDesC8@@XZ @ 10 NONAME ; class TDesC8 const & PKCS12::CDecPkcs12CertBag::CertValue(void) const
	?DecryptedData@CDecPkcs12SafeContents@PKCS12@@QBEPBVTDesC8@@XZ @ 11 NONAME ; class TDesC8 const * PKCS12::CDecPkcs12SafeContents::DecryptedData(void) const
	?DigestInfo@CDecPkcs12MacData@PKCS12@@QBEABVCPKCS7DigestInfo@@XZ @ 12 NONAME ; class CPKCS7DigestInfo const & PKCS12::CDecPkcs12MacData::DigestInfo(void) const
	?IntegrityMode@CDecPkcs12@PKCS12@@QBE?AW4TIntegrityMode@12@XZ @ 13 NONAME ; enum PKCS12::CDecPkcs12::TIntegrityMode PKCS12::CDecPkcs12::IntegrityMode(void) const
	?IterationCount@CDecPkcs12MacData@PKCS12@@QBEHXZ @ 14 NONAME ; int PKCS12::CDecPkcs12MacData::IterationCount(void) const
	?MacData@CDecPkcs12@PKCS12@@QBEPBVCDecPkcs12MacData@2@XZ @ 15 NONAME ; class PKCS12::CDecPkcs12MacData const * PKCS12::CDecPkcs12::MacData(void) const
	?MacSalt@CDecPkcs12MacData@PKCS12@@QBEABVTDesC8@@XZ @ 16 NONAME ; class TDesC8 const & PKCS12::CDecPkcs12MacData::MacSalt(void) const
	?NewL@CDecPkcs12@PKCS12@@SAPAV12@AAVRReadStream@@@Z @ 17 NONAME ; class PKCS12::CDecPkcs12 * PKCS12::CDecPkcs12::NewL(class RReadStream &)
	?NewL@CDecPkcs12@PKCS12@@SAPAV12@ABVTDesC8@@@Z @ 18 NONAME ; class PKCS12::CDecPkcs12 * PKCS12::CDecPkcs12::NewL(class TDesC8 const &)
	?NewL@CDecPkcs12Attribute@PKCS12@@SAPAV12@ABVTDesC8@@@Z @ 19 NONAME ; class PKCS12::CDecPkcs12Attribute * PKCS12::CDecPkcs12Attribute::NewL(class TDesC8 const &)
	?NewL@CDecPkcs12CertBag@PKCS12@@SAPAV12@ABVTDesC8@@@Z @ 20 NONAME ; class PKCS12::CDecPkcs12CertBag * PKCS12::CDecPkcs12CertBag::NewL(class TDesC8 const &)
	?NewL@CDecPkcs12KeyBag@PKCS12@@SAPAV12@ABVTDesC8@@@Z @ 21 NONAME ; class PKCS12::CDecPkcs12KeyBag * PKCS12::CDecPkcs12KeyBag::NewL(class TDesC8 const &)
	?NewL@CDecPkcs12MacData@PKCS12@@SAPAV12@ABVTDesC8@@0@Z @ 22 NONAME ; class PKCS12::CDecPkcs12MacData * PKCS12::CDecPkcs12MacData::NewL(class TDesC8 const &, class TDesC8 const &)
	?NewL@CDecPkcs12SafeBag@PKCS12@@SAPAV12@ABVTDesC8@@@Z @ 23 NONAME ; class PKCS12::CDecPkcs12SafeBag * PKCS12::CDecPkcs12SafeBag::NewL(class TDesC8 const &)
	?NewL@CDecPkcs12SafeContents@PKCS12@@SAPAV12@ABVCPKCS7ContentInfo@@@Z @ 24 NONAME ; class PKCS12::CDecPkcs12SafeContents * PKCS12::CDecPkcs12SafeContents::NewL(class CPKCS7ContentInfo const &)
	?NewL@CDecPkcs12SafeContents@PKCS12@@SAPAV12@ABVCPKCS7ContentInfo@@ABVTDesC16@@@Z @ 25 NONAME ; class PKCS12::CDecPkcs12SafeContents * PKCS12::CDecPkcs12SafeContents::NewL(class CPKCS7ContentInfo const &, class TDesC16 const &)
	?NewL@CDecPkcs12SafeContents@PKCS12@@SAPAV12@ABVTDesC8@@@Z @ 26 NONAME ; class PKCS12::CDecPkcs12SafeContents * PKCS12::CDecPkcs12SafeContents::NewL(class TDesC8 const &)
	?NewL@CDecPkcs12SafeContentsBag@PKCS12@@SAPAV12@ABVTDesC8@@@Z @ 27 NONAME ; class PKCS12::CDecPkcs12SafeContentsBag * PKCS12::CDecPkcs12SafeContentsBag::NewL(class TDesC8 const &)
	?NewL@CDecPkcs12ShroudedKeyBag@PKCS12@@SAPAV12@ABVTDesC8@@@Z @ 28 NONAME ; class PKCS12::CDecPkcs12ShroudedKeyBag * PKCS12::CDecPkcs12ShroudedKeyBag::NewL(class TDesC8 const &)
	?NewLC@CDecPkcs12@PKCS12@@SAPAV12@AAVRReadStream@@@Z @ 29 NONAME ; class PKCS12::CDecPkcs12 * PKCS12::CDecPkcs12::NewLC(class RReadStream &)
	?NewLC@CDecPkcs12@PKCS12@@SAPAV12@ABVTDesC8@@@Z @ 30 NONAME ; class PKCS12::CDecPkcs12 * PKCS12::CDecPkcs12::NewLC(class TDesC8 const &)
	?PrivateKeyInfoL@CDecPkcs12KeyBag@PKCS12@@QBEPAVCDecPKCS8Data@@XZ @ 31 NONAME ; class CDecPKCS8Data * PKCS12::CDecPkcs12KeyBag::PrivateKeyInfoL(void) const
	?PrivateKeyInfoL@CDecPkcs12ShroudedKeyBag@PKCS12@@QBEPAVCDecPKCS8Data@@AAVTDesC16@@@Z @ 32 NONAME ; class CDecPKCS8Data * PKCS12::CDecPkcs12ShroudedKeyBag::PrivateKeyInfoL(class TDesC16 &) const
	?SafeBags@CDecPkcs12SafeContentsBag@PKCS12@@QBEABV?$RPointerArray@VCDecPkcs12SafeBag@PKCS12@@@@XZ @ 33 NONAME ; class RPointerArray<class PKCS12::CDecPkcs12SafeBag> const & PKCS12::CDecPkcs12SafeContentsBag::SafeBags(void) const
	?SafeContentsBags@CDecPkcs12SafeContents@PKCS12@@QBEABV?$RPointerArray@VCDecPkcs12SafeBag@PKCS12@@@@XZ @ 34 NONAME ; class RPointerArray<class PKCS12::CDecPkcs12SafeBag> const & PKCS12::CDecPkcs12SafeContents::SafeContentsBags(void) const
	?VerifyIntegrityL@CDecPkcs12MacData@PKCS12@@QBEHABVTDesC16@@@Z @ 35 NONAME ; int PKCS12::CDecPkcs12MacData::VerifyIntegrityL(class TDesC16 const &) const
	?Version@CDecPkcs12@PKCS12@@QBEHXZ @ 36 NONAME ; int PKCS12::CDecPkcs12::Version(void) const
	?X509CertificateL@CDecPkcs12CertBag@PKCS12@@QBEPAVCX509Certificate@@XZ @ 37 NONAME ; class CX509Certificate * PKCS12::CDecPkcs12CertBag::X509CertificateL(void) const

